/* System call error numbers.
 * May be found in 'errno' after an error has occurred.
 *
 * These should be obtained from sys.l somehow.
 *
 */
#if !defined(_ERRNO_H)
#define _ERRNO_H 

#define E_ILLFNC	0x40	/* illegal function code				*/
#define E_FMTERR	0x41	/* format error							*/
#define E_NOTNUM	0x42	/* number not found/not a number		*/
#define E_ILLARG	0x43	/* illegal argument						*/

#define E_BUSERR	0x66	/* bus error TRAP 2 occurred			*/
#define E_ADRERR	0x67	/* address error TRAP 3 occurred		*/
#define E_ILLINS	0x68	/* illegal instruction TRAP 4 occurred	*/
#define E_ZERDIV	0x69	/* zero divide TRAP 5 occurred			*/
#define E_CHK		0x6a	/* CHK instruction TRAP 6 occurred		*/
#define E_TRAPV		0x6b	/* TrapV instruction TRAP 7 occurred	*/
#define E_VIOLAT	0x6c	/* privelage violation TRAP 8 occurred	*/
#define E_TRACE		0x6d	/* Uninitialized Trace TRAP 9 occurred	*/
#define E_1010		0x6e	/* Uninitialized 1010 TRAP 10 occurred	*/
#define E_1111		0x6f	/* Uninitialized 1111 TRAP 11 occurred	*/
#define E_TRAP		0x85	/* user traps 1-15 E_TRAP+n				*/
#define E_FPUNORDC	0x94	/* FP unordered condition error			*/
#define E_FPINXACT	0x95	/* FP inexact result					*/
#define E_FPDIVZER	0x96	/* FP zero divisor						*/
#define E_FPUNDRFL	0x97	/* FP underflow							*/
#define E_FPOPRERR	0x98	/* FP operand error						*/
#define E_FPOVERFL	0x99	/* FP overflow							*/
#define E_FPNOTNUM	0x9a	/* FP not a number						*/

#define E_PERMIT	0xa4	/* You must be super user to do that	*/
#define E_DIFFER	0xa5	/* Arguments to F$ChkNam are different	*/
#define E_STKOVF	0xa6	/* Stack overflow (ChkNam)				*/
#define E_EVNTID	0xa7	/* Invalid or Illegal event ID number	*/
#define E_EVNF		0xa8	/* Event (name) not found				*/
#define E_EVBUSY	0xa9	/* The event is busy (can't be deleted)	*/
#define E_EVPARM	0xaa	/* Impossible Event parameters supplied	*/
#define E_DAMAGE	0xab	/* System data structures are damaged	*/
#define E_BADREV	0xac	/* Incompatible revision				*/
#define E_PTHLOST	0xad	/* Path Lost (net node was down)		*/
#define E_BADPART	0xae	/* Bad partition data or no active		*/
							/* partition							*/
#define E_HARDWARE	0xaf	/* Hardware is damaged					*/
#define E_SECTSIZE	0xb0	/* Invalid sector size					*/

#define E_PTHFUL	0xc8	/* Path Table full						*/
#define E_BPNUM		0xc9	/* Bad Path Number						*/
#define E_POLL		0xca	/* Polling Table Full					*/
#define E_BMODE		0xcb	/* Bad Mode								*/
#define E_DEVOVF	0xcc	/* Device Table Overflow				*/
#define E_BMID		0xcd	/* Bad Module ID						*/
#define E_DIRFUL	0xce	/* Module Directory Full				*/
#define E_MEMFUL	0xcf	/* Process Memory Full					*/
#define E_UNKSVC	0xd0	/* Unknown Service Code					*/
#define E_MODBSY	0xd1	/* Module Busy							*/
#define E_BPADDR	0xd2	/* Bad Page Address						*/
#define E_EOF		0xd3	/* End of File							*/
#define E_VCTBSY	0xd4	/* IRQ Vector is already used			*/
#define E_NES		0xd5	/* Non-Existing Segment					*/
#define E_FNA		0xd6	/* File Not Accesible					*/
#define E_BPNAM		0xd7	/* Bad Path Name						*/
#define E_PNNF		0xd8	/* Path Name Not Found					*/
#define E_SLF		0xd9	/* Segment List Full					*/
#define E_CEF		0xda	/* Creating Existing File				*/
#define E_IBA		0xdb	/* Illegal Block Address				*/
#define E_HANGUP	0xdc	/* Phone hangup occurred (modem)		*/
#define E_MNF		0xdd	/* Module Not Found						*/
#define E_NOCLK		0xde	/* System has no clock running			*/
#define E_DELSP		0xdf	/* Deleting Stack Pointer memory		*/
#define E_IPRCID	0xe0	/* Illegal Process ID					*/
#define E_PARAM		0xe1	/* Impossible polling parameter specified*/
#define E_NOCHLD	0xe2	/* No Children							*/
#define E_ITRAP		0xe3	/* Invalid or unavailable Trap code		*/
#define E_PRCABT	0xe4	/* Process Aborted						*/
#define E_PRCFUL	0xe5	/* Process Table Full					*/
#define E_IFORKP	0xe6	/* Illegal Fork Parameter				*/
#define E_KWNMOD	0xe7	/* Known Module							*/
#define E_BMCRC		0xe8	/* Bad Module CRC						*/
#define E_USIGP		0xe9	/* Unprocessed Signal Pending (obsolescent)*/
#define E_SIGNAL	0xe9	/* Signal Error (replaces E_USIGP)		*/
#define E_NEMOD		0xea	/* Non Existing Module					*/
#define E_BNAM		0xeb	/* Bad Name								*/
#define E_BMHP		0xec	/* bad module header parity				*/
#define E_NORAM		0xed	/* No Ram Available						*/
#define E_DNE		0xee	/* Directory not empty					*/
#define E_NOTASK	0xef	/* No available Task number				*/
#define E_UNIT		0xf0	/* Illegal Unit (drive)					*/
#define E_SECT		0xf1	/* Bad SECTor number					*/
#define E_WP		0xf2	/* Write Protect						*/
#define E_CRC		0xf3	/* Bad Check Sum						*/
#define E_READ		0xf4	/* Read Error							*/
#define E_WRITE		0xf5	/* Write Error							*/
#define E_NOTRDY	0xf6	/* Device Not Ready						*/
#define E_SEEK		0xf7	/* Seek Error							*/
#define E_FULL		0xf8	/* Media Full							*/
#define E_BTYP		0xf9	/* Bad Type (incompatible) media		*/
#define E_DEVBSY	0xfa	/* Device Busy							*/
#define E_DIDC		0xfb	/* Disk ID Change						*/
#define E_LOCK		0xfc	/* Record is busy (locked out)			*/
#define E_SHARE		0xfd	/* Non-sharable file busy				*/
#define E_DEADLK	0xfe	/* I/O Deadlock error					*/
#define E_FORMAT	0xff	/* Device is format protected			*/

/* 0x600 through 0x6ff RAVE */
#define E_GFM_BASE	0x600				/* GFM error code base */
#define	E_ILLPRM	(E_GFM_BASE+0)		/* illegal parameter */
#define	E_IDFULL	(E_GFM_BASE+1)		/* identifier table full */
#define	E_BADSIZ	(E_GFM_BASE+2)		/* bad size error */
#define	E_RGFULL	(E_GFM_BASE+3)		/* region definition full */
#define	E_UNID		(E_GFM_BASE+4)		/* unallocated identifier number */
#define	E_NULLRG	(E_GFM_BASE+5)		/* null region */
#define	E_BADMOD	(E_GFM_BASE+6)		/* bad drawmap / pattern mode */
#define	E_NOFONT	(E_GFM_BASE+7)		/* no active font */
#define	E_NODM		(E_GFM_BASE+8)		/* no drawmap */
#define E_NOPLAY	(E_GFM_BASE+9)		/* no play/record is in progress */
#define E_ABORT		(E_GFM_BASE+10)		/* marks a play/record as aborted */
#define E_QFULL		(E_GFM_BASE+11)		/* audio queue is full */
#define E_BUSY		(E_GFM_BASE+12)		/* audio device is busy */

#define E_GSL_BASE		0x664			/* GSL error code base */
#define	E_RES_BASE		(E_GSL_BASE+0)	/* errors for resource manager */
#define	E_RES_NOSLOT	(E_RES_BASE+0)	/* No free slot in the table	*/
#define E_RES_BADSLOT	(E_RES_BASE+1)	/* The slot is bad 				*/
#define	E_RES_NOSHARE	(E_RES_BASE+2)	/* The resource is not sharable */
#define E_RES_NOTYPE	(E_RES_BASE+3)	/* The type is bad 				*/
#define E_RES_NORES		(E_RES_BASE+4)	/* The ID of the resource is bad */

#define E_REQ_BASE 	  (E_GSL_BASE+10)	/* errors for request manager */
#define E_REQ_NOITEMS (E_REQ_BASE+0)	/* request has no items */
#define E_REQ_BADITEM (E_REQ_BASE+1)	/* item number out of range */
#define E_REQ_BADCOLS  (E_REQ_BASE+2)	/* request has bad num. columns */
#define E_REQ_BADPTR  (E_REQ_BASE+3)	/* bad pointer for item array */
#define E_REQ_NOCREATE (E_REQ_BASE+4)	/* request hasn't been created */
#define E_REQ_TIMEOUT (E_REQ_BASE+5)	/* request has timed out */
#define E_REQ_NOSEL	  (E_REQ_BASE+6)	/* no selection has been made */
#define E_REQ_DEFID   (E_REQ_BASE+7)	/* bad definition id */
#define E_REQ_DEFACT  (E_REQ_BASE+8)	/* bad definition action code */
#define E_REQ_STATE   (E_REQ_BASE+9)	/* illegal item state */
#define E_REQ_BADRECT (E_REQ_BASE+10) 	/* illegal request rectangle */

#define	E_CNT_BASE		(E_GSL_BASE+30)	/* errors for control manager */
#define	E_CNT_BHVID		(E_CNT_BASE+0)	/* bad standard behavior id */
#define	E_CNT_DEFID		(E_CNT_BASE+1)	/* bad standard definition id */
#define	E_CNT_DEFACT	(E_CNT_BASE+2)	/* bad action for definition function */
#define	E_CNT_BHVACT	(E_CNT_BASE+3)	/* bad action for behavior function */
#define	E_CNT_STATE		(E_CNT_BASE+4)	/* bad control state */
#define	E_CNT_PART		(E_CNT_BASE+5)	/* bad control part code */
#define	E_CNT_FLAGS		(E_CNT_BASE+6)	/* bad flags */
#define	E_CNT_MINMAX	(E_CNT_BASE+7)	/* bad min, bad max or value out of range */
#define E_CNT_TYPE		(E_CNT_BASE+8)	/* bad type of control */

#define E_CLIP_BASE	(E_GSL_BASE+40) /* errors for clipboard manager */
#define E_CLIP_DEV	(E_CLIP_BASE+0)	/* can't find clipboard default device from preferences */
#define E_CLIP_FULL	(E_CLIP_BASE+1)	/* clipboard is full (attempt to write too many different types in clipboard) */
#define E_CLIP_TYPE	(E_CLIP_BASE+2)	/* type not currently represented in clipboard */
#define E_CLIP_ACC	(E_CLIP_BASE+3)	/* clipboard not opened for the requested access */
#define E_CLIP_CNT	(E_CLIP_BASE+4)	/* type offset greater than type count */
#define E_CLIP_OPEN	(E_CLIP_BASE+5)	/* clipboard not currently opened */
#define E_CLIP_INIT	(E_CLIP_BASE+6)	/* clipboard not initialized */
#define E_CLIP_CLOSE	(E_CLIP_BASE+7)	/* clipboard is not currently closed */
#define E_CLIP_RW	(E_CLIP_BASE+8)	/* can't rewrite - type not represented in clipboard */

#define E_HNDLR_BASE 	(E_GSL_BASE+50) /* errors for dispatch manager */
#define E_HNDLR_UNKNOWN (E_HNDLR_BASE+0)

#define E_ATBL_BASE 	(E_GSL_BASE+55) /* errors for association table routines */
#define E_ATBL_NOENTRY  (E_ATBL_BASE+0)	/* no entry found */

#define E_BOX_BASE		(E_GSL_BASE+60)		/* errors for ed_box function  */
#define E_BOX_TABLE		(E_BOX_BASE+0)		/* line table overflow */
#define E_BOX_COUNT		(E_BOX_BASE+1)		/* text too long (max = 65535 characters) */
#define E_BOX_TYPE		(E_BOX_BASE+2)		/* bad type or type not implemented */
#define E_BOX_MAXL		(E_BOX_BASE+3)		/* attempt to draw too long line (max is 1024 chars) */
#define E_BOX_NOTAB		(E_BOX_BASE+4)		/* need a line table (if the BOX_F_USETAB flag is set in the "type" parameter) */
#define E_BOX_NOFONT	(E_BOX_BASE+5)		/* font not set in the drawmap */
#define E_BOX_RECT		(E_BOX_BASE+6)		/* bad rectangle */

#define E_INIT_BASE		(E_GSL_BASE+80)		/* errors for init function */
#define E_INIT_VARERR	(E_INIT_BASE+0)

#define E_INTER_BASE	(E_GSL_BASE+85)
#define E_INTER_NOMOD	(E_INTER_BASE+0)	/* no preference module */
#define E_INTER_ILLARG	(E_INTER_BASE+1)	/* illegal arguement */

#define	E_OVL_BASE 		(E_GSL_BASE+90)		/* overlay window errors */
#define E_OVL_BADRECT 	(E_OVL_BASE+0)		/* bad rectangle for overlay */
#define E_OVL_NOTTOP	(E_OVL_BASE+1)		/* not top of overlay stack */
#define E_OVL_UNKNOWN	(E_OVL_BASE+2)		/* unknown overlay */

#define E_IND_BASE		(E_GSL_BASE+100)	/* indicator manager errors */
#define E_IND_DEFID		(E_IND_BASE+0)		/* bad definition id */
#define E_IND_DEFACT	(E_IND_BASE+1)		/* bad action for def. function */
#define E_IND_MINMAX	(E_IND_BASE+2)		/* bad min, max or value out of range */
#define E_IND_BADCORDS	(E_IND_BASE+3)		/* bad coordinates for indicator */
#define E_IND_NOCREATE	(E_IND_BASE+4)		/* attempt op. on non-created ind. */
#define E_IND_BADFLAGS 	(E_IND_BASE+5)		/* bad flag combination */
#define E_IND_BADPTR	(E_IND_BASE+6)		/* bad pointer in structure */
#define E_IND_BADDISP	(E_IND_BASE+7)		/* bad displacement */

/* 0x700 through 0x7ff IFF */
#define E_IFF_BASE 			((7<<8)+000)	/* base error code for IFF */
#define	E_IFF_RONLY 		(E_IFF_BASE+1)	/* this path is read-only */
#define	E_IFF_WONLY 		(E_IFF_BASE+2)	/* this path is write-only */
#define	E_IFF_ACTFORM 		(E_IFF_BASE+3)	/* there is no FORM active */
#define	E_IFF_READER 		(E_IFF_BASE+4)	/* wrong reader for this type of FORM */
#define	E_IFF_NOTIFF 		(E_IFF_BASE+5)	/* not an IFF file */
#define	E_IFF_BADPARM 		(E_IFF_BASE+6)	/* bad parameters */
#define	E_IFF_BADCAT 		(E_IFF_BASE+7)	/* bad CAT id (for iff_open) */
#define	E_IFF_SIZE_UNKNOWN 	(E_IFF_BASE+8)	/* cannot skip, size is unknown */
#define	E_IFF_NOT_DATA 		(E_IFF_BASE+9)	/* not to the data yet */
#define E_IFF_PIPE_SEEK 	(E_IFF_BASE+10)	/* attempt to seek back in a pipe */
#define	E_IFF_BADCHUNKSIZE	(E_IFF_BASE+11)	/* fixed size chunk was not the 
												correct size.  Could indicate 
												wrong version of reader */
#define E_IFF_FPNOTNUM		(E_IFF_BASE+12)	/* can't make float conversion */

/* 0x700 is for Ethernet */
#define EWOULDBLOCK		0x701	/* I/O operation would block */
#define EINPROGRESS		0x702	/* I/O operation now in progress */
#define EALREADY		0x703	/* operation already in progress */
#define EDESTADDRREQ	0x704	/* destination address required */
#define EMSGSIZE		0x705	/* message too long */
#define EPROTOTYPE		0x706	/* protocol wrong type for socket */
#define ENOPROTOOPT		0x707	/* bad protocol option */
#define EPROTONOSUPPORT 0x708	/* protocol not supported */
#define ESOCKNOSUPPORT	0x709	/* socket type not supported */
#define EOPNOTSUPP		0x70a	/* operation not supported on socket */
#define EPFNOSUPPORT	0x70b	/* protocol family not supported */
#define EAFNOSUPPORT	0x70c	/* address family not supported by protocol */
#define EADDRINUSE		0x70d	/* address already in use */
#define EADDRNOTAVAIL	0x70e	/* can't assign requested address */
#define ENETDOWN		0x70f	/* network is down */
#define ENETUNREACH		0x710	/* network is unreachable */
#define ENETRESET		0x711	/* network dropped connection on reset */
#define ECONNABORTED	0x712	/* software caused connection abort */
#define ECONNRESET		0x713	/* connection reset by peer */
#define ENOBUFS			0x714	/* no buffer space available */
#define EISCONN			0x715	/* socket is already connected */
#define ENOTCONN		0x716	/* socket is not connected */
#define ESHUTDOWN		0x717	/* can't send after socket shutdown */
#define ETOOMANYREFS	0x718	/* too many references */
#define ETIMEDOUT		0x719	/* connection timed out */
#define ECONNREFUSED	0x71a	/* connection refused by target */
#define EBUFTOOSMALL	0x71b	/* mbuf too small for mbuf operation	*/
#define ESMODEXISTS		0x71c	/* socket module already attached		*/
#define ENOTSOCK		0x71d	/* path is not a socket					*/

/* Unix Spezial */
#define EIO			  5	/* I/O error 						*/
#define	ENXIO			  6	/* No such device or address 				*/
#define EBADF		E_BPNUM		/* invalid file number  				*/
#define EXDEV			 18	/* Cross-Link						*/
#define EINVAL		E_ILLARG	/* invalid argument					*/
#define EMFILE			 24	/* to many open files					*/
#define	ENOSPC			248	/* No space left on device 				*/
#define EFAULT		E_BPADDR	/* Bad Adress						*/
#define ENOENT		E_PNNF		/* File not found					*/
#define ENOMEM  	0xfffd     	/* Not enough core.					*/ 
#define ENOTTY		E_BMODE		/* Bad Mode						*/
#define ENOEXEC		E_BPNNF		/* File not found					*/
#define EPIPE		0xfffe	 	/* Broken Pipe						*/
#define	EINTR		E_ILLFNC	/* Unprocessed Signal Pending (obsolescent)		*/
#define EACCES		E_FNA		/* Permission denied					*/
#define EEXIST		E_CEF		/* File exists						*/
#define EPERM		E_PERMIT	/* Not Super-User					*/
#define ESRCH		E_IPRCID	/* No such process					*/
#define ENOTDIR		EBPNUM		/* Bad Path number fuer not Directory			*/



extern int errno;


#endif /* _ERRNO_H */
